﻿* Encoding: UTF-8.

* Syntax for the West European Politics article.
* 'Seat enlargements in mixed-member proportional systems: evidence from the German Laender'.
* by Philipp Weinmann and Florian Grotz.


* Load data.
* ATTENTION: Insert correct directory and - if necessary - file name here and for all graph templates (by replace).
* ATTENTION: The comma is used as decimal separator.
GET DATA 
  /TYPE=XLSX 
  /FILE='/INSERT_DIRECTORY_HERE/German_electoral_system_dataset.xlsx' 
  /SHEET=name 'Data' 
  /CELLRANGE=FULL 
  /READNAMES=ON 
  /DATATYPEMIN PERCENTAGE=95.0 
  /HIDDEN IGNORE=YES. 
EXECUTE. 
DATASET NAME MMPelections WINDOW=FRONT.

* Introduce variable labels.
VARIABLE LABELS 
land_eng 'Land' 
land_eng_at_large 'Land & MMP subtype'
land_eng_at_large2 'MMP subtype (Land)'
elec_year 'Election year'
dratio 'Ratio of SMD seats in regular parliament size (in %)'
levelling 'Levelling mode (1: full, 0.5: partial, 0: no levelling of surplus seats)'
ss 'Surplus seats occurred (1: yes; 0: no)'
ds_max 'Maximum SMD seat share'
qlv_max 'Maximum qualified list vote share'
enlarg_ss 'Basic enlargement'
enlarg_total 'Total enlargement'
p_ss 'Predicted basic enlargement'
p_full 'Predicted total enlargement'
p_partial 'Predicted total enlargement'
p_total 'Predicted total enlargement'
p_r_ss 'Predicted basic enlargement'
p_r_full 'Predicted total enlargement'
p_r_partial 'Predicted total enlargement'
p_r_total 'Predicted total enlargement'
p_ra_ss 'Predicted basic enlargement'
p_ra_total 'Predicted total enlargement'
p_rp_full 'Predicted total enlargement'
p_rp_total 'Predicted total enlargement'
p_rpa_total 'Predicted total enlargement'.

* Width and decimals.
FORMATS enlarg_ss enlarg_total p_ss p_full p_partial p_total p_r_ss p_r_full p_r_partial p_r_total p_ra_ss p_ra_total (f5.1).



* FIGURE 1 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=elec_year WITH enlarg_total BY land_eng 
  /MISSING=LISTWISE 
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 1.sgt'.
* Margins still have to be adapted.

FREQUENCIES VARIABLES=ss 
  /ORDER=ANALYSIS.



* FIGURE 3 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ss WITH enlarg_ss BY land_eng_at_large2 BY elec_year (IDENTIFY)
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 3.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted. 

FREQUENCIES VARIABLES=ss 
  /ORDER=ANALYSIS.



* FIGURE 3 without (West) Berlin (Filter + Scatterplot + Frequencies).
* used to calculate the alternative regression line without (West) Berlin cases.
USE ALL. 
COMPUTE filter_$=(mmp_laender_wo_west_berlin = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender_wo_west_berlin = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ss WITH enlarg_ss BY land_eng_at_large2 BY elec_year (IDENTIFY)
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 3.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted. 

FREQUENCIES VARIABLES=ss 
  /ORDER=ANALYSIS.



* FOOTNOTE
* Footnote: slightly deviant cases in Lower Saxony.
* Load data changed for Lower Saxony 1951 & 1955 (both sz_tot = 161, 1951 sz_ss = 161, 1955 sz_ss = 154).
* Source: Schröder, http://www.wahlen-in-deutschland.de/blNiedersachsen.htm.
GET DATA 
  /TYPE=XLSX 
  /FILE='/INSERT_DIRECTORY_HERE/German_electoral_system_dataset_LS_1951-1955.xlsx' 
  /SHEET=name 'Data' 
  /CELLRANGE=FULL 
  /READNAMES=ON 
  /DATATYPEMIN PERCENTAGE=95.0 
  /HIDDEN IGNORE=YES. 
EXECUTE. 
DATASET NAME MMPelections_LS.



* FIGURE 3 without (West) Berlin & changed values for Lower Saxony 1951 & 1955 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender_wo_west_berlin = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender_wo_west_berlin = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ss WITH enlarg_ss BY land_eng BY elec_year (IDENTIFY)
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 3 wo Berlin.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be compared with premade ones. 

FREQUENCIES VARIABLES=ss 
  /ORDER=ANALYSIS.

DATASET ACTIVATE MMPelections.
* FOOTNOTE END.



* FIGURE 4 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ra_ss WITH enlarg_ss BY land_eng_at_large2 BY elec_year (IDENTIFY)
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 4.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted. 

FREQUENCIES VARIABLES=ss 
  /ORDER=ANALYSIS.



* FIGURE 5 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ra_total WITH enlarg_total BY land_eng_at_large2 BY elec_year (IDENTIFY) 
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 5.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted.

FREQUENCIES VARIABLES=ss
  /ORDER=ANALYSIS.



* FIGURE 5 without Berlin (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender_wo_west_berlin = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_ra_total WITH enlarg_total BY land_eng_at_large2 BY elec_year (IDENTIFY) 
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 5.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted.

FREQUENCIES VARIABLES=ss
  /ORDER=ANALYSIS.



* FIGURE 6 (Filter + Scatterplot + Frequencies).
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=p_rpa_total WITH enlarg_total BY land_eng_at_large2 BY elec_year (IDENTIFY) 
  /MISSING=LISTWISE
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure 6.sgt'.
* Margins and fit line still have to be adapted and default regression text boxes to be deleted.

FREQUENCIES VARIABLES=ss
  /ORDER=ANALYSIS.



* APPENDIX.

* TABLE A.2 (Filter + Regression Output + R Square for predicted vs. real).
* create interaction variable.
COMPUTE ds_max_dratio=ds_max * dratio.
EXECUTE.

* including (West) Berlin.
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT enlarg_ss
  /METHOD=ENTER ds_max dratio ds_max_dratio qlv_max
  /SAVE PRED (p_ss_OLS_all).

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT enlarg_ss
  /METHOD=ENTER p_ss_OLS_all.

* excluding (West) Berlin.
USE ALL. 
COMPUTE filter_$=(mmp_laender_wo_west_berlin = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender_wo_west_berlin = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT enlarg_ss
  /METHOD=ENTER ds_max dratio ds_max_dratio qlv_max
  /SAVE PRED (p_ss_OLS_woBE).

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT enlarg_ss
  /METHOD=ENTER p_ss_OLS_woBE.



* FIGURE A.1 (Filter + Scatterplot).
* Data used for Chapter 4 when choosing scenarios of 45% and 35% as Maximum QLV share.
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=elec_year WITH qlv_max BY land_eng 
  /MISSING=LISTWISE 
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure A.1.sgt'.
* Margins still have to be adapted.


* FIGURE A.2 (Filter + Scatterplot).
* Joint distribution of Maximum SMD seat share and Maximum QLV share.
USE ALL. 
COMPUTE filter_$=(mmp_laender = 1 & ss_possible > 0). 
VARIABLE LABELS filter_$ 'mmp_laender = 1 & ss_possible > 0 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.

GRAPH 
  /SCATTERPLOT(BIVAR)=qlv_max WITH ds_max BY land_eng BY elec_year (IDENTIFY) 
  /MISSING=LISTWISE 
  /TEMPLATE='/INSERT_DIRECTORY_HERE/Figure A.2.sgt'.
* Margins still have to be adapted.

